# General guidelines

Please see https://ck.readthedocs.io/en/latest/guide/how-to-contribute.html

**Thank you very much for supporting this community project!**

# Contributors

```
N: Grigori Fursin (alias: FGG)
E: Grigori.Fursin@cTuning.org
H: https://fursin.net
O: cTuning foundation, France
C: original concept and prototyping, real-world use cases, development of https://cKnowledge.org and https://cKnowledge.io
W: since Nov.1, 2014 

N: Anton Lokhmotov
E: anton@dividiti.com
H: https://www.hipeac.net/~anton
O: dividiti, UK
C: real-world use cases
W: since Mar.1, 2015

N: Graham Markall
E: graham.markall@continuum.io
O: Continuum Analytics, UK
C: feedback on basic usage and help with Conda packaging (Anaconda scientific python distribution)
W: 

N: Alexey Kravets
E: 
H: 
O: ARM, UK
C: discussing possible PENCIL autotuning scenarios via CK (within CARP project)
W: 

N: Sven van Haastregt
E: 
H: 
O: ARM, UK
C: discussing possible PENCIL autotuning scenarios via CK (within CARP project)
W: 

N: Vincent Grevendonk
E: 
H: 
O: ARM, UK
C: discussing possible PENCIL autotuning scenarios via CK (within CARP project)
W: 

N: Abdul Wahid Memon
E: engrwahidmemon@gmail.com
O: 
C: checking how to convert GCC optimization flags to CK format for autotuning
W: 

N: Valentin Dalibard
E: valentin.dalibard@cl.cam.ac.uk
O: University of Cambridge, UK
C: feedback on autotuning and run-time adaptation
W: 

N: Eiko Yoneki
E: eiko.yoneki@cl.cam.ac.uk
O: University of Cambridge, UK
C: feedback on autotuning and run-time adaptation
W: 

N: Cedric Nugteren
E: web@cedricnugteren.nl
O: The Netherlands
C: testing CK on MacOS, validating OpenCL autotuning 
W: 

N: Sergey Yakushkin
E: 
O: Synopsys
C: feedback, suggestions 
W: 

N: Lucas Nussbaum
E:
O: Universite de Lorraine, France
C: feedback on Debian packaging
W:

N: Andrei Lascu
E: andrei.lascu10@imperial.ac.uk
O: Imperial College, UK
C: including clsmith to CK (OpenCL compiler testing)
W: 

N: Alastair Donaldson
E: alastair.donaldson@imperial.ac.uk
O: Imperial College, UK
C: including clsmith to CK (OpenCL compiler testing)
W: 

N: Egor Pasko
E: 
O: Google
C: feedback on basic usage
W: 

N: Gianfranco Costamagna
E:
O: 
C: feedback on Debian packaging
W:

N: Michael Kruse
E: MichaelKruse@meinersbur.de
O: ENS Paris, France
C: evaluating CK-based gemmbench (http://github.com/dividiti/gemmbench)
   and providing feedback about autotuning and experiment reproducibility
W:

N: Chandan Reddy Gopal 
E: 
O: ENS Paris, France
C: evaluating CK for polyhedral autotuning (Pencil and PPCG from CARP project)
   and providing various feedback
W:

N: Michel Steuwer 
E: 
O: University of Edinburgh, UK
C: feedback about documentation
W:

N: Ed Plowman 
E: 
O: ARM, UK
C: CK feedback and discussions 
W:

N: Luigi Nardi 
E: 
O: STMicroelectronics, France
C: testing GCC crowdtuning engine and reporting a few minor bugs
W:

N: Michael Haidl
E:
H:
O: 
C: helping test ARM64-based mobile phone to crowdsource optimizations

N: Toomas Remmelg
E:
H:
O: University of Edinburgh, UK
C: helping test ARM64-based Android mobile devices (flags and OpenCL)

N: Christophe Guillon 
E: 
O: STMicroelectronics, France
C: testing GCC crowdtuning engine and reporting a few minor bugs
W:

N: Leonid Fursin
E:
O: 
C: feedback about crowdtuning on Samsung T-900 tablet
W:

N: Jiahao Chen
E:
O: MIT, USA
C: discussions about Julia language and CK-based performance autotuning
W:

N: Jarrett Revels
E:
O: MIT, USA
C: discussions about Julia performane tuning and feedback about CK-based LLVM crowdtuning on MacOS
W:

N: Aaron Smith
E:
O: Microsoft, USA
C: general discussions, feedback and help to move CK to Azure cloud (http://cknowledge.org)
W:

N: Dave Wilkinson
E:
O: University of Pittsburgh, USA
C: evaluating CK and providing several suggestions on usability
W:

N: Kenan Kalajdzic
E:
O:
C: reporting vulnerability in CK public repository (fixed)
W:

N: Yuriy Kashnikov 
E:
O: Xored
C: crowd-tuning discussions
W:

N: Dmitry Savenko 
E:
O: Xored
C: added continuous integration, various tests and fixed various problems with crowdtuning on MacOS 
W:

N: Daniil Efremov 
E:
O: Xored
C: testing and improving CK
W:

N: Michael Mcgeagh
E:
O: ARM, UK
C: reporting problem with YAML recording and CPU feature detection (in new format)
W:

N: Chris Cummins
E:
O: University of Edinburgh, UK
C: reporting problem with the 'ck status'
W:

N: Sam Ainsworth
E:
O: University of Cambridge, UK
C: reporting a few issues when converting his CGO 2017 artifacts to CK format (https://github.com/SamAinsworth/reproduce-cgo2017-paper)
W:

N: Nikolay Istomin
E:
O: Xored
C: fixed issue with widget fetching data from another source
W:

N: Todd Gamblin
E:
O: LLNL
C: discussing how to connect CK and spack, and fixing detection of native LLVM on MacOS (https://github.com/ctuning/ck-env/pull/70)
W:

N: Dave Greasley
E:
O: University of Bristol
C: fixed problem with repo UID when installing CK repo as zip:
   * https://github.com/ctuning/ck/pull/92
   * https://github.com/ctuning/ck/issues/91
   provided feedback about RPi crowd-tuning: http://cKnowledge.org/rpi-crowd-tuning
W:

N: Stephen Herbein
E: 
O: LLNL
C: customizing kernel to search soft in Spack directories
W: https://herbein.net

N: Flavio Vella
E: 
O: Free University of Bozen-Bolzano
C: feedback, support and contribution of CK workflows and components
W: 

N: Ivan Ospiov
E: 
O: Xored
C: reported a problem with shared-repos.html; general feedback
W: 

N: Leo Gordon
E: 
O: dividiti
C: feedback, support and improvements
W: 

N: Herve Guillou
E: 
O: CodeReef
C: testing and feedback
W: 

N: Vincent Rehm
E: 
O: CodeReef
C: testing and feedback with LinuxBrew
W: 

N: Thibaut Dumontet
E: 
O: CodeReef
C: testing and feedback with LinuxBrew
W: 

N: Alex Redshaw
E: 
O: Arm
C: feedback about installation issue with Python 2.7
W: 

N: Patrick Hesse
E: 
O: College of Saint Benedict and Saint John's University, USA
C: adding CK tutorial for March Madness sample program
W: 

N: Emanuele Vitali
E: 
O: 
C: ML auto-tuning R&D
W: 

N: Gavin Simpson
E: 
O: 
C: MLPerf workflows
W: 

```
